import { Middleware, Dispatch, SubscribeAction, UnsubscribeAction, Manager, Schema, State } from '@rest-hooks/core';
/** Properties sent to Subscription constructor */
export interface SubscriptionInit {
    schema?: Schema;
    fetch: () => Promise<any>;
    key: string;
    getState: () => State<unknown>;
    frequency?: number;
}
/** Interface handling a single resource subscription */
export interface Subscription {
    add(frequency?: number): void;
    remove(frequency?: number): boolean;
    cleanup(): void;
}
/** The static class that constructs Subscription */
export interface SubscriptionConstructable {
    new (init: SubscriptionInit, dispatch: Dispatch<any>): Subscription;
}
/** Handles subscription actions -> fetch or receive actions
 *
 * Constructor takes a SubscriptionConstructable class to control how
 * subscriptions are handled. (e.g., polling, websockets)
 */
export default class SubscriptionManager<S extends SubscriptionConstructable> implements Manager {
    protected subscriptions: {
        [key: string]: InstanceType<S>;
    };
    protected readonly Subscription: S;
    protected middleware: Middleware;
    constructor(Subscription: S);
    /** Ensures all subscriptions are cleaned up. */
    cleanup(): void;
    /** Called when middleware intercepts 'rest-hooks/subscribe' action.
     *
     */
    protected handleSubscribe(action: SubscribeAction, dispatch: Dispatch<any>, getState: () => State<unknown>): void;
    /** Called when middleware intercepts 'rest-hooks/unsubscribe' action.
     *
     */
    protected handleUnsubscribe(action: UnsubscribeAction, dispatch: Dispatch<any>): void;
    /** Attaches Manager to store
     *
     * Intercepts 'rest-hooks/subscribe'/'rest-hooks/unsubscribe' to register resources that
     * need to be kept up to date.
     *
     * Will possibly dispatch 'rest-hooks/fetch' or 'rest-hooks/receive' to keep resources fresh
     *
     */
    getMiddleware<T extends SubscriptionManager<any>>(this: T): Middleware;
}
//# sourceMappingURL=SubscriptionManager.d.ts.map
